+ Example commands

      BioSAK get_GTDB_taxon_gnm -p Bac -meta bac120_metadata_r202.tsv -path genome_paths.tsv -taxon taxons.txt -cpl 85 -ctm 5
      BioSAK get_GTDB_taxon_gnm -p Arc -meta ar122_metadata_r202.tsv -path genome_paths.tsv -taxon taxons.txt -cpl 50 -ctm 10

+ -meta: bac120_metadata_r202.tsv or ar122_metadata_r202.tsv

+ -path: genome_paths.tsv, in fastani folder from auxillary_files

+ -taxon: one taxon per line, example below:

      p__Thermoproteota
      c__Methanosarcinia
      f__Thalassarchaeaceae
