
### Badge examples
[![github repo-size](https://img.shields.io/github/followers/songweizhi.svg?label=Follow)]()
[![github repo-size](https://img.shields.io/github/forks/songweizhi/Binning_refiner.svg?label=Fork)]()
[![github repo-size](https://img.shields.io/github/stars/songweizhi/Binning_refiner.svg)]()
[![github repo-size](https://img.shields.io/github/stars/songweizhi/Binning_refiner.svg?style=social)]()
[![github repo-size](https://img.shields.io/github/watchers/songweizhi/Binning_refiner.svg?label=Watch)]()
[![github issues](https://img.shields.io/github/issues/songweizhi/Binning_refiner.svg)]()
[![DOI](https://img.shields.io/static/v1.svg?label=DOI&message=10.1093/bioinformatics/btx086&color=orange)](https://doi.org/10.1093/bioinformatics/btx086)


Some examples of Markdown syntax
---

https://confluence.atlassian.com/bitbucketserver/markdown-syntax-guide-776639995.html#Markdownsyntaxguide-Markdownsyntax

http://daringfireball.net/projects/markdown/syntax

# This is an H1
## This is an H2
### This is an H3
#### This is an H4
##### This is an H5
###### This is an H6

*This is an Italic characters*

_This is also an Italic characters_

**This is a bold characters**

__This is also a bold characters__

~~strikethrough~~

* Item 1
  * Item 1.1
    * Item 1.1.1


1. Step 1
   1. Step 1.1
        1. Step 1.1.1

Introducing my quote:
> This is the first level of quoting.
>
>> This is nested blockquote.
>
> Back to the first level.


Use the backtick to refer to a `function()`. There is a literal ``backtick (`)`` here.


This is [an example](http://www.example.com/) inline link.

[This link](http://example.com/ "Title") has a title attribute.

Links are also auto-detected in text: http://example.com/

| Day     | Meal    | Price |
| --------|---------|-------|
| Monday  | pasta   | $6    |
| Tuesday | chicken | $8    |
